==> vlc-debug-1:3.0.22-5-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-a89e30a4d2cb156b8a4f68aa52b11ebd0d8eb25a/modules/gui/qt/medialibrary_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0x57,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x8e,0x4,0x6d,0xa,0x0,0xa2,0xa,0x22,0x19,0x60,0xd7,0x3,
  0x2b,0x21,0xa4,0xbb,0x84,0xda,0xc3,0x22,0xae,0x2b,0x0,0xb7,0x53,0x68,0x8b,0x53,
  0xe6,0x56,0x47,0xcb,0x10,0x6,0xde,0x14,0x42,0xf5,0xa2,0x4d,0x95,0x23,0x77,0xc3,
  0x7f,0x72,0x32,0xb,0xbe,0xe4,0x50,0x3f,0xed,0xc5,0x6f,0x63,0x88,0xb5,0x77,0x12,
  0x29,0xb4,0x9c,0x72,0x67,0xae,0xdc,0xb0,0xe4,0xcd,0x36,0xd7,0x5f,0x6a,0x47,0x49,
  0x6d,0x2d,0xa9,0xc6,0x20,0xd4,0x41,0xb7,0x57,0x26,0x3d,0x2b,0x33,0x1b,0x37,0x51,
  0xfe,0x52,0x65,0xcc,0x6,0xe0,0x53,0x13,0x82,0x41,0x20,0x82,0x6f,0x4a,0xe1,0x61,
  0xab,0x84,0xaf,0xc4,0x6f,0x0,0xef,0x21,0xe,0xf5,0x7c,0x6a,0xf,0x6b,0xaf,0x8,
  0xbe,0xaf,0x7e,0xb,0x74,0xf,0xbf,0x92,0xe,0x94,0xb1,0x1f,0x1,0x71,0xa8,0xa0,
  0x3d,0xc7,0x3a,0x3,0x68,0xa8,0x21,0x53,0x98,0x49,0x51,0x2a,0x95,0x61,0xe,0x20,
  0x44,0x48,0xad,0xe2,0x1c,0x21,0x8,0x4a,0x9,0x10,0x42,0x88,0x11,0x65,0xd8,0x6a,
  0xd9,0x33,0x20,0xae,0xb1,0x83,0x1,0x87,0xe4,0x61,0x45,0x36,0x3f,0x4e,0x18,0x6a,
  0x2c,0x3d,0x77,0x55,0xa0,0x90,0x72,0x55,0x73,0x38,0xbd,0x9e,0x75,0xec,0x18,0xa8,
  0xe,0x69,0xa5,0xe7,0xcb,0xe9,0x3b,0xc9,0x6a,0x20,0x89,0x8c,0xc5,0xd6,0x1b,0xbb,
  0xad,0xe0,0xaf,0xb,0x47,0xd,0x80,0x3,0x61,0x57,0x44,0xfb,0x92,0x7e,0x98,0xc7,
  0x34,0xf3,0xf8,0x28,0x65,0x43,0xb5,0x41,0xae,0xcc,0xd9,0xe1,0xd2,0xb4,0xac,0xd2,
  0xa5,0x89,0x11,0xd5,0xaa,0x5a,0x78,0x20,0x86,0x18,0xe4,0x92,0xc2,0xb0,0xd1,0xb4,
  0x65,0x39,0x46,0x66,0xb8,0xd3,0xcd,0xdd,0xe9,0xdc,0xa1,0x16,0xb0,0x77,0xc2,0x75,
  0x1d,0xd,0x61,0x58,0x25,0x50,0x6d,0x1c,0x7a,0x85,0x42,0x7c,0xc2,0xfa,0x47,0x8e,
  0x9a,0x20,0x32,0xfc,0x60,0x2e,0x71,0x2c,0x51,0x6a,0xc4,0x8f,0xf8,0x22,0x52,0x38,
  0xfe,0x52,0xdb,0x83,0xd0,0x20,0x3c,0x88,0x3,0x61,0xb1,0x87,0x2e,0xf5,0x92,0x26,
  0xbf,0x2b,0x2a,0x89,0x52,0xab,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // MediaLibrary
  0x0,0xc,
  0x8,0x8e,0xd6,0x59,
  0x0,0x4d,
  0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x61,0x0,0x4c,0x0,0x69,0x0,0x62,0x0,0x72,0x0,0x61,0x0,0x72,0x0,0x79,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0x7e,0x57,0x35,0xe0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0x7e,0x57,0x35,0xe0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9a,0x7e,0x57,0x35,0xe0,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9a,0x7e,0x57,0x35,0xe0,
  // :/qt/qml/VLC/MediaLibrary
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9a,0x7e,0x57,0x35,0xe0,
  // :/qt/qml/VLC/MediaLibrary/qmldir
  0x0,0x0,0x0,0x40,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x7e,0x57,0x35,0xe0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> vlc-debug-1:3.0.22-6-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-a89e30a4d2cb156b8a4f68aa52b11ebd0d8eb25a/modules/gui/qt/medialibrary_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0x57,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x8e,0x4,0x6d,0xa,0x0,0xa2,0xa,0x22,0x19,0x60,0xd7,0x3,
  0x2b,0x21,0xa4,0xbb,0x84,0xda,0xc3,0x22,0xae,0x2b,0x0,0xb7,0x53,0x68,0x8b,0x53,
  0xe6,0x56,0x47,0xcb,0x10,0x6,0xde,0x14,0x42,0xf5,0xa2,0x4d,0x95,0x23,0x77,0xc3,
  0x7f,0x72,0x32,0xb,0xbe,0xe4,0x50,0x3f,0xed,0xc5,0x6f,0x63,0x88,0xb5,0x77,0x12,
  0x29,0xb4,0x9c,0x72,0x67,0xae,0xdc,0xb0,0xe4,0xcd,0x36,0xd7,0x5f,0x6a,0x47,0x49,
  0x6d,0x2d,0xa9,0xc6,0x20,0xd4,0x41,0xb7,0x57,0x26,0x3d,0x2b,0x33,0x1b,0x37,0x51,
  0xfe,0x52,0x65,0xcc,0x6,0xe0,0x53,0x13,0x82,0x41,0x20,0x82,0x6f,0x4a,0xe1,0x61,
  0xab,0x84,0xaf,0xc4,0x6f,0x0,0xef,0x21,0xe,0xf5,0x7c,0x6a,0xf,0x6b,0xaf,0x8,
  0xbe,0xaf,0x7e,0xb,0x74,0xf,0xbf,0x92,0xe,0x94,0xb1,0x1f,0x1,0x71,0xa8,0xa0,
  0x3d,0xc7,0x3a,0x3,0x68,0xa8,0x21,0x53,0x98,0x49,0x51,0x2a,0x95,0x61,0xe,0x20,
  0x44,0x48,0xad,0xe2,0x1c,0x21,0x8,0x4a,0x9,0x10,0x42,0x88,0x11,0x65,0xd8,0x6a,
  0xd9,0x33,0x20,0xae,0xb1,0x83,0x1,0x87,0xe4,0x61,0x45,0x36,0x3f,0x4e,0x18,0x6a,
  0x2c,0x3d,0x77,0x55,0xa0,0x90,0x72,0x55,0x73,0x38,0xbd,0x9e,0x75,0xec,0x18,0xa8,
  0xe,0x69,0xa5,0xe7,0xcb,0xe9,0x3b,0xc9,0x6a,0x20,0x89,0x8c,0xc5,0xd6,0x1b,0xbb,
  0xad,0xe0,0xaf,0xb,0x47,0xd,0x80,0x3,0x61,0x57,0x44,0xfb,0x92,0x7e,0x98,0xc7,
  0x34,0xf3,0xf8,0x28,0x65,0x43,0xb5,0x41,0xae,0xcc,0xd9,0xe1,0xd2,0xb4,0xac,0xd2,
  0xa5,0x89,0x11,0xd5,0xaa,0x5a,0x78,0x20,0x86,0x18,0xe4,0x92,0xc2,0xb0,0xd1,0xb4,
  0x65,0x39,0x46,0x66,0xb8,0xd3,0xcd,0xdd,0xe9,0xdc,0xa1,0x16,0xb0,0x77,0xc2,0x75,
  0x1d,0xd,0x61,0x58,0x25,0x50,0x6d,0x1c,0x7a,0x85,0x42,0x7c,0xc2,0xfa,0x47,0x8e,
  0x9a,0x20,0x32,0xfc,0x60,0x2e,0x71,0x2c,0x51,0x6a,0xc4,0x8f,0xf8,0x22,0x52,0x38,
  0xfe,0x52,0xdb,0x83,0xd0,0x20,0x3c,0x88,0x3,0x61,0xb1,0x87,0x2e,0xf5,0x92,0x26,
  0xbf,0x2b,0x2a,0x89,0x52,0xab,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // MediaLibrary
  0x0,0xc,
  0x8,0x8e,0xd6,0x59,
  0x0,0x4d,
  0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x61,0x0,0x4c,0x0,0x69,0x0,0x62,0x0,0x72,0x0,0x61,0x0,0x72,0x0,0x79,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0xa6,0xfe,0xe8,0xf8,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0xa6,0xfe,0xe8,0xf8,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9a,0xa6,0xfe,0xe8,0xf8,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9a,0xa6,0xfe,0xe8,0xf8,
  // :/qt/qml/VLC/MediaLibrary
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9a,0xa6,0xfe,0xe8,0xf8,
  // :/qt/qml/VLC/MediaLibrary/qmldir
  0x0,0x0,0x0,0x40,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0xa6,0xfe,0xe8,0xf8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
